const Alt = require('./../src');

describe('All', () => {
  test('should pass', async () => {
    const hasError = await Alt({
      foo: Alt.string(),
      number: Alt.number(),
      bool: Alt.boolean(),
      array: Alt.array(),
      function: Alt.function(),
      date: Alt.date(),
      internetUrl: Alt.internet().url(),
      object: Alt.object()
    }).body({
      foo: 'bar',
      number: 1,
      bool: true,
      array: [],
      function: () => true,
      date: new Date(),
      internetUrl: 'http://localhost/',
      object: { foo: 'bar' }
    }).validate();
    expect(hasError).toBe(false);
  });


  test('should fail', async () => {
    const hasError = await Alt({
      foo: Alt.string(),
      number: Alt.number(),
      bool: Alt.boolean(),
      array: Alt.array(),
      function: Alt.function(),
      date: Alt.date(),
      internetUrl: Alt.internet().url(),
      object: Alt.object()
    }).body({
      foo: 1,
      number: 'bar',
      bool: [],
      array: 'foo',
      function: new Date(),
      date: () => true,
      internetUrl: 1,
      object: []
    }).validate();
    expect(hasError).toHaveLength(8);
    expect(hasError).toMatchSnapshot();
  });


  test('should fail nested', async () => {
    const hasError = await Alt({
      foo: Alt.array().oneOf(Alt.string()),
      object: Alt.object().schema(Alt({
        bar: Alt.string()
      }))
    }).body({
      foo: [1, 'foo', 'b', [], 'ar'],
      object: { bar: 1 }
    }).validate();
    expect(hasError).toHaveLength(2);
    expect(hasError).toMatchSnapshot();
  });
});
